@@ -17,7 +17,7 @@ use App::VTide::Hooks;
 use Path::Tiny;
 use YAML::Syck qw/ LoadFile DumpFile /;
 
-our $VERSION = version->new('0.0.1');
+our $VERSION = version->new('0.0.2');
 
 has config => (
     is      => 'rw',
@@ -145,7 +145,7 @@ App::VTide - A vim/tmux baised IDE for the terminal
 
 =head1 VERSION
 
-This documentation refers to App::VTide version 0.0.1
+This documentation refers to App::VTide version 0.0.2
 
 =head1 SYNOPSIS
 
@@ -171,11 +171,12 @@ This documentation refers to App::VTide version 0.0.1
 
 =head1 DESCRIPTION
 
-VTide is the programmatic expression of my workflow. It uses the C<tmux>
-terminal multiplexer to start multiple terminals and run vim (and other
-editors/programs/commands) in each terminal. The aim is to start a L<vtide>
-with everything open and working straight up. This workflow helps to
-isolate work into small sections.
+VTide provides a way to manage L<tmux> sessions. It allows for an easy way
+to configure a session window and run programs or open files for editing
+in them. The aim is to allow for easy project setup and management for
+projects managed on the command line. L<App::VTide> also includes helpers
+for loading files into editors (such as vim) in seperate tmux terminals.
+This can help to open pre-defined groups of files.
 
 =head2 Philosophy
 
